==> cxf-testutils-2.0.6.13-fuse-sources.jar: org/apache/locator/types/RegisterEndpoint.java <==

package org.apache.locator.types;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.cxf.ws.addressing.EndpointReferenceType;


/**
 * Input message element for "registerEndpoint" operation.
 * 
 * <p>Java class for registerEndpoint element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="registerEndpoint">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="endpoint_id" type="{http://apache.org/locator/types}EndpointIdentity"/>
 *           &lt;element name="endpoint_reference" type="{http://www.w3.org/2005/08/addressing}EndpointReferenceType"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "endpointId",
    "endpointReference"
})
@XmlRootElement(name = "registerEndpoint")
public class RegisterEndpoint {

    @XmlElement(name = "endpoint_id", required = true)
    protected EndpointIdentity endpointId;
    @XmlElement(name = "endpoint_reference", required = true)
    protected EndpointReferenceType endpointReference;

    /**
     * Gets the value of the endpointId property.
     * 
     * @return
     *     possible object is
     *     {@link EndpointIdentity }
     *     
     */
    public EndpointIdentity getEndpointId() {
        return endpointId;
    }

    /**
     * Sets the value of the endpointId property.
     * 
     * @param value
     *     allowed object is
     *     {@link EndpointIdentity }
     *     
     */
    public void setEndpointId(EndpointIdentity value) {
        this.endpointId = value;
    }

    /**
     * Gets the value of the endpointReference property.
     * 
     * @return
     *     possible object is
     *     {@link EndpointReferenceType }
     *     
     */
    public EndpointReferenceType getEndpointReference() {
        return endpointReference;
    }

    /**
     * Sets the value of the endpointReference property.
     * 
     * @param value
     *     allowed object is
     *     {@link EndpointReferenceType }
     *     
     */
    public void setEndpointReference(EndpointReferenceType value) {
        this.endpointReference = value;
    }

}

==> cxf-testutils-2.1.3.3-fuse-sources.jar: org/apache/locator/types/RegisterEndpoint.java <==

package org.apache.locator.types;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import javax.xml.ws.wsaddressing.W3CEndpointReference;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="endpoint_id" type="{http://apache.org/locator/types}EndpointIdentity"/>
 *         &lt;element name="endpoint_reference" type="{http://www.w3.org/2005/08/addressing}EndpointReferenceType"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "endpointId",
    "endpointReference"
})
@XmlRootElement(name = "registerEndpoint")
public class RegisterEndpoint {

    @XmlElement(name = "endpoint_id", required = true)
    protected EndpointIdentity endpointId;
    @XmlElement(name = "endpoint_reference", required = true)
    protected W3CEndpointReference endpointReference;

    /**
     * Gets the value of the endpointId property.
     * 
     * @return
     *     possible object is
     *     {@link EndpointIdentity }
     *     
     */
    public EndpointIdentity getEndpointId() {
        return endpointId;
    }

    /**
     * Sets the value of the endpointId property.
     * 
     * @param value
     *     allowed object is
     *     {@link EndpointIdentity }
     *     
     */
    public void setEndpointId(EndpointIdentity value) {
        this.endpointId = value;
    }

    /**
     * Gets the value of the endpointReference property.
     * 
     * @return
     *     possible object is
     *     {@link W3CEndpointReference }
     *     
     */
    public W3CEndpointReference getEndpointReference() {
        return endpointReference;
    }

    /**
     * Sets the value of the endpointReference property.
     * 
     * @param value
     *     allowed object is
     *     {@link W3CEndpointReference }
     *     
     */
    public void setEndpointReference(W3CEndpointReference value) {
        this.endpointReference = value;
    }

}
